@@ -15,17 +15,4 @@ def generate_csrf(directory):
     with open(filename, 'w') as f:
         f.write(_csrf)
     print "Injecting cookie dependency"
-    update_dependencies(directory, 'ngCookies')
-
-if __name__ == '__main__':
-    generate_csrf('../..')
-
-
-
-
-
-
-
-
-
-
+    update_dependencies(directory, 'ngCookies')
\ No newline at end of file
