@@ -1,5 +1,6 @@
 import os
 
+from angular_scaffold._docs import docs as scaffolding_docs
 styling_docs = """#Style Guide
 
 This project uses SASS. All styles are stored in `/assets/lib/styles/`.
@@ -125,12 +126,5 @@ def generate_docs(directory):
         os.makedirs(os.path.join(directory, 'docs'))
     with (open(os.path.join(directory, 'docs', 'styling.md'), 'w')) as f:
         f.write(styling_docs)
-    current_path = os.path.dirname(__file__)
-    components = current_path.split(os.sep)
-    root = components[:-3]
-    root.append('README.md')
-    readme = os.sep + os.path.join(*root)
-    with open(readme, 'r') as fin:
-        scaffolding_docs = fin.read()
     with (open(os.path.join(directory, 'docs', 'scaffold.md'), 'w')) as f:
         f.write(scaffolding_docs)
\ No newline at end of file
