@@ -10,14 +10,14 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         if hasattr(settings, 'BASE_DIR'):
-            dir = settings.BASE_DIR
+            directory = settings.BASE_DIR
         else:
-            dir = '.'
+            directory = '.'
         if not args:
             controller_name = raw_input("Name of the controller: ")
-            generate_controller(dir, controller_name)
+            generate_controller(directory, controller_name)
             self.stdout.write('Successfully initialized controller "%s"' % controller_name)
         else:
             for controller_name in args:
-                generate_controller(dir, controller_name)
+                generate_controller(directory, controller_name)
                 self.stdout.write('Successfully initialized controller "%s"' % controller_name)
